#!/bin/sh
#
# DVB Troubleshooting Script
#
# This script helps diagnose issues with DVB frontend access
#

# Stop Enigma2 service
echo "Stopping Enigma2 service..."
systemctl stop enigma2 2>/dev/null || killall -9 enigma2 2>/dev/null
sleep 2

# Check for available adapters and frontends
echo "Checking available DVB devices..."
if [ -d "/dev/dvb" ]; then
    for adapter in /dev/dvb/adapter*; do
        echo "Found $adapter"
        ls -la $adapter
    done
else
    echo "No DVB devices found in /dev/dvb"
fi

# Try to open each frontend to check availability
echo -e "\nTesting frontend availability..."
for frontend in /dev/dvb/adapter*/frontend*; do
    echo "Testing $frontend..."
    # Try to open the device
    if cat $frontend >/dev/null 2>&1; then
        echo "FAILED: $frontend is in use or inaccessible"
    else
        echo "OK: $frontend appears to be available"
    fi
done

# Check if DVB daemons are running
echo -e "\nChecking for DVB processes..."
ps | grep dvb

# Try a simple tuning operation on available frontends
echo -e "\nAttempting simple tuning on available frontends..."
for adapter in 0 1 2 3; do
    for frontend in 0 1 2 3; do
        device="/dev/dvb/adapter${adapter}/frontend${frontend}"
        if [ -e "$device" ]; then
            echo "Trying adapter $adapter frontend $frontend ($device)..."
            ./pid_extractor_poc 4139000 0 $adapter $frontend
            echo "Exit code: $?"
        fi
    done
done

echo -e "\nRestarting Enigma2..."
systemctl start enigma2 2>/dev/null || init 3 2>/dev/null

echo -e "\nTroubleshooting complete."